@@ -263,14 +263,19 @@ class ELReps():
         return score, mvsEle
 
     def suppress_traces(self,logsimple, sup):
+        max_removed = 0
         for key in logsimple.keys():
+            count_removed = 0
             list_trace = logsimple[key]['trace']
             for i in range(len(list_trace)-1, -1, -1):
                 sub = list_trace[i]
                 if sub in sup:
                     list_trace.remove(sub)
+                    count_removed += 1
+            if count_removed > max_removed:
+                max_removed = count_removed
             logsimple[key]['trace'] = list_trace
-        return logsimple
+        return logsimple, max_removed
 
     def create_trace(self, case, trace_attributes, life_cycle, all_life_cycle, life_cycle_prefix, time_prefix, bk_type,sensitive_attributes,time_accuracy, from_create_event_log):
         sens = {}
@@ -410,12 +415,13 @@ class ELReps():
                             except:
                                 daysOfmonth = monthrange(log[i][j]['time:timestamp'].year, 1 + month)[1]
                                 if days >= daysOfmonth:
-                                    daydiff = days - daysOfmonth
-                                    month += 1
-                                    days = daydiff
+                                    # daydiff = days - daysOfmonth
+                                    # month += 1
+                                    # days = daydiff
+                                    days = daysOfmonth
                                 log[i][j]['time:timestamp'] = datetime.datetime(year=base_year + years,
                                                                                 month=1 + month,
-                                                                                day=1 + days, hour=hours,
+                                                                                day=days, hour=hours,
                                                                                 minute=minutes, second=sectim)
                     elif spectime == "minutes":
                         if starttime == 0:
@@ -443,13 +449,13 @@ class ELReps():
                             except:
                                 daysOfmonth = monthrange(log[i][j]['time:timestamp'].year, 1+ month)[1]
                                 if days >= daysOfmonth:
-                                    daydiff = days - daysOfmonth
-                                    month += 1
-                                    days = daydiff
+                                    days = daysOfmonth
                                 log[i][j]['time:timestamp'] = datetime.datetime(year=base_year + years,
                                                                                 month=1 + month,
-                                                                                day=1 + days, hour=hours,
+                                                                                day= days, hour=hours,
                                                                                 minute=minutes, second=0)
+
+
                     elif spectime == "hours":
                         if starttime == 0:
                             starttime = log[i][j]['time:timestamp']
@@ -474,12 +480,10 @@ class ELReps():
                             except:
                                 daysOfmonth = monthrange(log[i][j]['time:timestamp'].year, 1 + month)[1]
                                 if days >= daysOfmonth:
-                                    daydiff = days - daysOfmonth
-                                    month += 1
-                                    days = daydiff
+                                    days = daysOfmonth
                                 log[i][j]['time:timestamp'] = datetime.datetime(year=base_year + years,
                                                                                 month=1 + month,
-                                                                                day=1 + days, hour=hours, minute=0,
+                                                                                day= days, hour=hours, minute=0,
                                                                                 second=0)
                     elif spectime == "days":
                         if starttime == 0:
@@ -505,12 +509,10 @@ class ELReps():
                             except:
                                 daysOfmonth = monthrange(log[i][j]['time:timestamp'].year, 1 + month)[1]
                                 if days >= daysOfmonth:
-                                    daydiff = days - daysOfmonth
-                                    month += 1
-                                    days = daydiff
+                                    days = daysOfmonth
                                 log[i][j]['time:timestamp'] = datetime.datetime(year=base_year + years,
                                                                                 month=1 + month,
-                                                                                day=1 + days, hour=0, minute=0,
+                                                                                day= days, hour=0, minute=0,
                                                                                 second=0)
                     elif spectime == "original":
                         pass
